@@ -87,58 +87,61 @@ class TextRankSummarizerFormatter(FormatterBase, ProcessorBase, ABC):
 
         nlp = get_nlp(lang, params.algo.value)
         doc = _check_sentences(nlp, params.algo.value, document)
-        sent_bounds = [[s.start, s.end, set([])] for s in doc.sents]
-        num_sentences = int_float(params.num_sentences)
-        limit_sentences = (
-            round(len(sent_bounds) * num_sentences)
-            if isinstance(num_sentences, float)
-            else num_sentences
-        )
-        phrase_id = 0
-        unit_vector = []
-        for p in doc._.phrases:
-            unit_vector.append(p.rank)
-            for chunk in p.chunks:
-                for sent_start, sent_end, sent_vector in sent_bounds:
-                    if chunk.start >= sent_start and chunk.end <= sent_end:
-                        sent_vector.add(phrase_id)
-                        break
-            phrase_id += 1
-            if phrase_id == params.num_phrases:
-                break
+        if doc.has_annotation("SENT_START"):
+            sent_bounds = [[s.start, s.end, set([])] for s in doc.sents]
+            num_sentences = int_float(params.num_sentences)
+            limit_sentences = (
+                round(len(sent_bounds) * num_sentences)
+                if isinstance(num_sentences, float)
+                else num_sentences
+            )
+            phrase_id = 0
+            unit_vector = []
+            for p in doc._.phrases:
+                unit_vector.append(p.rank)
+                for chunk in p.chunks:
+                    for sent_start, sent_end, sent_vector in sent_bounds:
+                        if chunk.start >= sent_start and chunk.end <= sent_end:
+                            sent_vector.add(phrase_id)
+                            break
+                phrase_id += 1
+                if phrase_id == params.num_phrases:
+                    break
 
-        sum_ranks = sum(unit_vector)
+            sum_ranks = sum(unit_vector)
 
-        unit_vector = [rank / sum_ranks for rank in unit_vector]
+            unit_vector = [rank / sum_ranks for rank in unit_vector]
 
-        sent_rank = {}
-        sent_id = 0
-        for sent_start, sent_end, sent_vector in sent_bounds:
-            sum_sq = 0.0
-            for phrase_id in range(len(unit_vector)):
-                if phrase_id not in sent_vector:
-                    sum_sq += unit_vector[phrase_id] ** 2.0
-            sent_rank[sent_id] = sqrt(sum_sq)
-            sent_id += 1
-        # sorted(sent_rank.items(), key=itemgetter(1))
-        sent_text = {}
-        sent_id = 0
-        for sent in doc.sents:
-            sent_text[sent_id] = sent.text.strip()
-            sent_id += 1
-        num_sent = 0
-        summary_sentences = {}
-        for sent_id, rank in sorted(sent_rank.items(), key=itemgetter(1)):
-            summary_sentences[sent_id] = sent_text[sent_id]
-            num_sent += 1
-            if num_sent == limit_sentences:
-                break
-        if params.preserve_order:
-            summary_sents = [
-                v for k, v in sorted(summary_sentences.items(), key=itemgetter(0))
-            ]
+            sent_rank = {}
+            sent_id = 0
+            for sent_start, sent_end, sent_vector in sent_bounds:
+                sum_sq = 0.0
+                for phrase_id in range(len(unit_vector)):
+                    if phrase_id not in sent_vector:
+                        sum_sq += unit_vector[phrase_id] ** 2.0
+                sent_rank[sent_id] = sqrt(sum_sq)
+                sent_id += 1
+            # sorted(sent_rank.items(), key=itemgetter(1))
+            sent_text = {}
+            sent_id = 0
+            for sent in doc.sents:
+                sent_text[sent_id] = sent.text.strip()
+                sent_id += 1
+            num_sent = 0
+            summary_sentences = {}
+            for sent_id, rank in sorted(sent_rank.items(), key=itemgetter(1)):
+                summary_sentences[sent_id] = sent_text[sent_id]
+                num_sent += 1
+                if num_sent == limit_sentences:
+                    break
+            if params.preserve_order:
+                summary_sents = [
+                    v for k, v in sorted(summary_sentences.items(), key=itemgetter(0))
+                ]
+            else:
+                summary_sents = list(summary_sentences.values())
         else:
-            summary_sents = list(summary_sentences.values())
+            summary_sents = [document.text]
         return summary_sents
 
     def format(self, document: Document, parameters: FormatterParameters) -> Response:
